@@ -25,7 +25,7 @@ spaces, etc.
 
 from jedi_toolz import config
 from jedi_toolz.show import *
-from jedi_toolz import xlsx
+from jedi_toolz.xlsx import *
 from jedi_toolz import domo
 from jedi_toolz.data import *
 from jedi_toolz.str_funcs import *
\ No newline at end of file
